/*
 * skillchains-db-xul.js
 *
 * Copyright (c) 2004 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the FFXI Skillchains JS Library.
 *
 * The FFXI Skillchains JS Library is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FFXI Skillchains JS Library is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the FFXI Skillchains JS Library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * Controls the XUL database system.
 */

function initDatabase() {
    try {
	// Start building the tree view of the database...
	var tree = document.getElementById("weaponsTreeChildren");
	var container, item, row, cell, elements;
	for (var w in SkillChainDB.weapons) {
	    item = document.createElement("treeitem");
	    item.setAttribute("container", "true");
	    item.setAttribute("open", "false");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    cell.setAttribute("label", SkillChainDB.weapons[w].name);
	    row.appendChild(cell);
	    container = document.createElement("treechildren");
	    item.appendChild(container);
	    tree.appendChild(item);
	    // now add the jobs
	    appendJobs(container, getLocalString("exjobs"), SkillChainDB.weapons[w].ex);
	    appendJobs(container, getLocalString("spjobs"), SkillChainDB.weapons[w].sp);
	    // now the skills (what everyone really wants to see :) )
	    item = document.createElement("treeitem");
	    container.appendChild(item);
	    item.setAttribute("container", "true");
	    item.setAttribute("open", "true");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    cell.setAttribute("label", getLocalString("weapon.skills"));
	    row.appendChild(cell);
	    container = document.createElement("treechildren");
	    item.appendChild(container);
	    for (var s in SkillChainDB.weapons[w].skills) {
		item = document.createElement("treeitem");
		container.appendChild(item);
		item.setAttribute("container", "false");
		row = document.createElement("treerow");
		item.appendChild(row);
		cell = document.createElement("treecell");
		cell.setAttribute("label", SkillChainDB.weapons[w].skills[s].name);
		row.appendChild(cell);
		// first element
		cell = document.createElement("treecell");
		if (SkillChainDB.weapons[w].skills[s].element == null) {
		    // no element (can't be used in a chain)
		    cell.setAttribute("label", "-");
		    elements = getLocalString("none");
		} else {
		    cell.setAttribute("src", icon(SkillChainDB.weapons[w].skills[s].element.icon));
		    elements = SkillChainDB.weapons[w].skills[s].element.name;
		}
		row.appendChild(cell);
		// second element
		cell = document.createElement("treecell");
		if (SkillChainDB.weapons[w].skills[s].element2 != null) {
		    cell.setAttribute("src", icon(SkillChainDB.weapons[w].skills[s].element2.icon));
		    elements += ", " + SkillChainDB.weapons[w].skills[s].element2.name;
		}
		row.appendChild(cell);
		// third element
		cell = document.createElement("treecell");
		if (SkillChainDB.weapons[w].skills[s].element3 != null) {
		    cell.setAttribute("src", icon(SkillChainDB.weapons[w].skills[s].element3.icon));
		    elements += ", " + SkillChainDB.weapons[w].skills[s].element3.name;
		}
		row.appendChild(cell);
		cell = document.createElement("treecell");
		cell.setAttribute("label", SkillChainDB.weapons[w].skills[s].level);
		row.appendChild(cell);
		cell = document.createElement("treecell");
		var flags = SkillChainDB.weapons[w].skills[s].flags;
		if (flags == WS_SP) {
		    cell.setAttribute("label", getLocalString("sp"));
		} else if (flags == WS_EX) {
		    cell.setAttribute("label", getLocalString("ex"));
		} else {
		    cell.setAttribute("label", "");
		}
		row.appendChild(cell);
		cell = document.createElement("treecell");
		cell.setAttribute("label", elements);
		row.appendChild(cell);
	    }
	}
	// Next, basically the same thing, except for the avatars
	tree = document.getElementById("avatarsTreeChildren");
	for (var a in SkillChainDB.avatars) {
	    // Do a quick run-through first to count the number of each
	    // type of blood pact, so we can create the items properly
	    var chainablePacts = 0;
	    var burstPacts = 0;
	    var otherPacts = 0;
	    for (var s in SkillChainDB.avatars[a].skills) {
		if (SkillChainDB.avatars[a].skills[s].flags & WS_BURST) {
		    burstPacts++;
		} else if (SkillChainDB.avatars[a].skills[s].element == null) {
		    otherPacts++;
		} else {
		    chainablePacts++;
		}
	    }
	    item = document.createElement("treeitem");
	    item.setAttribute("container", "true");
	    item.setAttribute("open", "false");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    cell.setAttribute("label", SkillChainDB.avatars[a].name);
	    row.appendChild(cell);
	    container = document.createElement("treechildren");
	    item.appendChild(container);
	    tree.appendChild(item);
	    // First display the skillchain skills (if any)
	    item = document.createElement("treeitem");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    row.appendChild(cell);
	    if (chainablePacts > 0) {
		cell.setAttribute("label", getLocalString("avatar.skillchain.skills"));
		item.setAttribute("container", "true");
		item.setAttribute("open", "true");
		var skillContainer = document.createElement("treechildren");
		item.appendChild(skillContainer);
		for (var s in SkillChainDB.avatars[a].skills) {
		    if (!(SkillChainDB.avatars[a].skills[s].flags & WS_BURST) && SkillChainDB.avatars[a].skills[s].element != null) {
			createAvatarSkillNode(skillContainer, SkillChainDB.avatars[a].skills[s]);
		    }
		}
	    } else {
		cell.setAttribute("label", getLocalString("avatar.no.skillchain.skills"));
	    }
	    container.appendChild(item);
	    // Then display the magic burst skills
	    item = document.createElement("treeitem");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    row.appendChild(cell);
	    if (burstPacts > 0) {
		cell.setAttribute("label", getLocalString("avatar.burst.skills"));
		item.setAttribute("container", "true");
		item.setAttribute("open", "true");
		var skillContainer = document.createElement("treechildren");
		item.appendChild(skillContainer);
		for (var s in SkillChainDB.avatars[a].skills) {
		    if (SkillChainDB.avatars[a].skills[s].flags & WS_BURST) {
			createAvatarSkillNode(skillContainer, SkillChainDB.avatars[a].skills[s]);
		    }
		}
	    } else {
		cell.setAttribute("label", getLocalString("avatar.no.burst.skills"));
	    }
	    container.appendChild(item);
	    // Finally display any remaining pacts
	    item = document.createElement("treeitem");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    row.appendChild(cell);
	    if (otherPacts > 0) {
		cell.setAttribute("label", getLocalString("avatar.normal.skills"));
		item.setAttribute("container", "true");
		item.setAttribute("open", "true");
		var skillContainer = document.createElement("treechildren");
		item.appendChild(skillContainer);
		for (var s in SkillChainDB.avatars[a].skills) {
		    if (!(SkillChainDB.avatars[a].skills[s].flags & WS_BURST) && SkillChainDB.avatars[a].skills[s].element == null) {
			createAvatarSkillNode(skillContainer, SkillChainDB.avatars[a].skills[s]);
		    }
		}
	    } else {
		cell.setAttribute("label", getLocalString("avatar.no.normal.skills"));
	    }
	    container.appendChild(item);
	}
	// Now: populate the elements
	tree = document.getElementById("elementsTreeChildren");
	var any = getLocalString("any");
	for (var e in SkillChainDB.elements) {
	    item = document.createElement("treeitem");
	    item.setAttribute("container", "true");
	    item.setAttribute("open", "false");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    cell.setAttribute("label", SkillChainDB.elements[e].name);
	    cell.setAttribute("src", icon(SkillChainDB.elements[e].icon));
	    row.appendChild(cell);
	    container = document.createElement("treechildren");
	    item.appendChild(container);
	    tree.appendChild(item);
	    // now add the elements this chains with
	    for (c in SkillChainDB.elements[e].chains) {
		item = document.createElement("treeitem");
		container.appendChild(item);
		item.setAttribute("container", "false");
		row = document.createElement("treerow");
		item.appendChild(row);
		cell = document.createElement("treecell");
		cell.setAttribute("label", SkillChainDB.elements[e].name);
		cell.setAttribute("src", icon(SkillChainDB.elements[e].icon));
		row.appendChild(cell);
		cell = document.createElement("treecell");
		cell.setAttribute("label", SkillChainDB.elements[e].chains[c].toElement.name);
		cell.setAttribute("src", icon(SkillChainDB.elements[e].chains[c].toElement.icon));
		row.appendChild(cell);
		cell = document.createElement("treecell");
		cell.setAttribute("label", SkillChainDB.elements[e].chains[c].chain.name);
		cell.setAttribute("src", chainIcon(SkillChainDB.elements[e].chains[c].chain.icon));
		row.appendChild(cell);
		cell = document.createElement("treecell");
		if (SkillChainDB.elements[e].chains[c].prevChain == null) {
		    cell.setAttribute("label", any);
		} else {
		    cell.setAttribute("label", SkillChainDB.elements[e].chains[c].prevChain.name);
		    cell.setAttribute("src", chainIcon(SkillChainDB.elements[e].chains[c].prevChain.icon));
		}
		row.appendChild(cell);
	    }
	}
    } catch (ex) {
	alert("d'oh: " + ex);
    }
}

function createAvatarSkillNode(container, skill) {
    var elements;
    var item = document.createElement("treeitem");
    container.appendChild(item);
    item.setAttribute("container", "false");
    var row = document.createElement("treerow");
    item.appendChild(row);
    var cell = document.createElement("treecell");
    cell.setAttribute("label", skill.name);
    row.appendChild(cell);
    // first element
    cell = document.createElement("treecell");
    if (skill.element == null) {
	// no element (can't be used in a chain)
	cell.setAttribute("label", "-");
	elements = getLocalString("none");
    } else {
	cell.setAttribute("src", icon(skill.element.icon));
	elements = skill.element.name;
    }
    row.appendChild(cell);
    // second element
    cell = document.createElement("treecell");
    if (skill.element2 != null) {
	cell.setAttribute("src", icon(skill.element2.icon));
	elements += ", " + skill.element2.name;
    }
    row.appendChild(cell);
    // third element
    cell = document.createElement("treecell");
    if (skill.element3 != null) {
	cell.setAttribute("src", icon(skill.element3.icon));
	elements += ", " + skill.element3.name;
    }
    row.appendChild(cell);
    cell = document.createElement("treecell");
    cell.setAttribute("label", skill.level);
    row.appendChild(cell);
    cell = document.createElement("treecell");
    var flags = skill.flags;
    if (flags & WS_ASTRALFLOW) {
	cell.setAttribute("label", "*");
    } else {
	cell.setAttribute("label", "");
    }
    row.appendChild(cell);
    cell = document.createElement("treecell");
    cell.setAttribute("label", elements);
    row.appendChild(cell);
}

function sendEmail() {
    open("mailto:dmpotter@xenoveritas.org?Subject=[FFXI SCT] Avatar Blood Pact Skill Chain Elements");
}

function icon(name) {
    return "chrome://skillchains/skin/elements/" + name + ".png";
}

function chainIcon(name) {
    return "chrome://skillchains/skin/sc/" + name + ".png";
}

function appendJobs(container, label, jobs) {
    var item = document.createElement("treeitem");
    container.appendChild(item);
    if (jobs != null && jobs.length >= 1) {
	item.setAttribute("container", "true");
	item.setAttribute("open", "true");
	var row = document.createElement("treerow");
	item.appendChild(row);
	var cell = document.createElement("treecell");
	cell.setAttribute("label", label);
	row.appendChild(cell);
	var children = document.createElement("treechildren");
	item.appendChild(children);
	for (var j in jobs) {
	    item = document.createElement("treeitem");
	    row = document.createElement("treerow");
	    item.appendChild(row);
	    cell = document.createElement("treecell");
	    cell.setAttribute("label", jobs[j].name);
	    row.appendChild(cell);
	    children.appendChild(item);
	}
    } else {
	var row = document.createElement("treerow");
	item.appendChild(row);
	var cell = document.createElement("treecell");
	cell.setAttribute("label", label + " (" + getLocalString("none") + ")");
	row.appendChild(cell);
    }
}
