/*
 * skillchains-options.js
 *
 * Copyright (c) 2004 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the FFXI Skillchains Tool.
 *
 * The FFXI Skillchains Tool is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FFXI Skillchains Tool is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the FFXI Skillchains Tool; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * Handles the setting and retrieving of options.
 */

var prefs = Components.classes["@mozilla.org/preferences-service;1"].
               getService(Components.interfaces.nsIPrefService);
prefs = prefs.getBranch("skillchains.");

var windowManager = Components.classes["@mozilla.org/appshell/window-mediator;1"].
		getService(Components.interfaces.nsIWindowMediator);

function init() {
    var arrowType = "image";
    var showElements = true;
    var showChainIcons = true;
    var showChainElements = true;
    var showChainElementNames = true;
    try {
	showElements = prefs.getBoolPref("elements");
    } catch (ex) { /* don't care */ }
    try {
	showChainElements = prefs.getBoolPref("elements.chain");
    } catch (ex) { /* don't care */ }
    try {
	showChainElementNames = prefs.getBoolPref("elements.chain.name");
    } catch (ex) { /* don't care */ }
    try {
	showChainIcons = prefs.getBoolPref("chain.icons");
    } catch (ex) { /* don't care */ }
    try {
	arrowType = prefs.getCharPref("arrow");
    } catch (ex) { /* don't care */ }
    document.getElementById("arrowGroup").selectedIndex = arrowType == "unicode" ? 1 : 0;
    document.getElementById("showSkillElements").checked = showElements;
    document.getElementById("showChainIcons").checked = showChainIcons;
    document.getElementById("showChainElements").checked = showChainElements;
    document.getElementById("showChainElementNames").checked = showChainElementNames;
}

function acceptChanges() {
    // called to commit current changes
    var arrowType = "image";
    if (document.getElementById("arrowUseUnicode").selected) {
	arrowType = "unicode";
    }
    var showChainIcons = document.getElementById("showChainIcons").checked;
    var showChainElements = document.getElementById("showChainElements").checked;
    var showChainElementNames = document.getElementById("showChainElementNames").checked;
    var showElements = document.getElementById("showSkillElements").checked;
    prefs.setCharPref("arrow", arrowType);
    prefs.setBoolPref("elements", showElements);
    prefs.setBoolPref("elements.chain", showChainElements);
    prefs.setBoolPref("elements.chain.name", showChainElementNames);
    prefs.setBoolPref("chain.icons", showChainIcons);
    // go through windows and start/stop the clock appropriately
    // also if the SC window is up, apply pref changes to it, too
    var windowEnum = windowManager.getEnumerator(null);
    while (windowEnum.hasMoreElements()) {
	var win = windowEnum.getNext();
	if (win.SkillChainDB && win.applyResultsOptions) {
	    win.applyResultsOptions();
	}
    }
}
